package com.xlht.xlhtproject.controller;


import com.xlht.xlhtproject.domain.HomeCountInfo;
import com.xlht.xlhtproject.domain.TShuju1;
import com.xlht.xlhtproject.domain.TTbDu;
import com.xlht.xlhtproject.mapper.TTbDuMapper;
import com.xlht.xlhtproject.respParse.bean.AjaxResult;
import com.xlht.xlhtproject.respParse.bean.R;
import com.xlht.xlhtproject.service.IFrontService;
import com.xlht.xlhtproject.service.ITShuju1Service;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

import static com.xlht.xlhtproject.enums.MyConstants.LONG_1;

/**
 * 前端用户相关接口
 */
@RestController
@RequestMapping("/front")
@Slf4j
public class FrontController {

    @Autowired
    private IFrontService frontService;

    @Autowired
    private TTbDuMapper tTbDuMapper;

    @Autowired
    private ITShuju1Service tShuju1Service;


    /**
     *
     * 智能投药系统获取实时需要数据接口
     * @return
     */
    @GetMapping("/bigModel/smartAdd/dataInfo")
    public AjaxResult smartAddDataInfo()
    {
        log.info("进入了 智能投药系统获取实时需要数据 接口");
        return AjaxResult.success(frontService.smartAddDataInfo());
    }


    /**
     * type说明：
     * 0：进水流量
     * 1：#1好氧池硝酸盐
     * 2：#2好氧池硝酸盐
     * 3：#1缺氧池氨氮
     * 4：#2缺氧池氨氮
     * 5：进水COD
     * 6：进水总氮
     * 7：碳源投加量
     *
     *
     * @param type
     * @return
     */
    @GetMapping("/bigModel/smartAdd/charList/{type}")
    public AjaxResult smartAddCharList(@PathVariable int type, @RequestParam(required = false, name = "timeBegin") String timeBegin, @RequestParam(required = false, name = "timeEnd") String timeEnd)
    {
        log.info("进入了 智能投药系统获取对应指标最近1天的数据情况 接口");
        return AjaxResult.success(frontService.smartAddCharList(type, timeBegin, timeEnd));
    }



    /**
     *获取碳源投加 是否在本系统中允许投放（用于部分场景：计算异常 或者 想手动中断等）
     * @return
     */
    @GetMapping("/bigModel/smartAdd/getSwitchStatus")
    public R<TTbDu> getSwitchStatus()
    {
        log.info("进入了 获取碳源投加 是否在本系统中允许投放（用于部分场景：计算异常 或者 想手动中断等） 接口");
        /*TTbDu tTbDu = tTbDuMapper.selectTTbDuByID(LONG_1);
        if(Objects.isNull(tTbDu))
            throw new RuntimeException("未查询到碳源投放配置开关");
        return R.ok(tTbDu.getACTIVE());*/
        return R.ok(tTbDuMapper.selectTTbDuByID(LONG_1));
    }


    /**
     *修改碳源投加 是否在本系统中允许投放（用于部分场景：计算异常 或者 想手动中断等）
     * @return
     */
    @PutMapping("/bigModel/smartAdd/updateSwitchStatus")
    public R<String> updateSwitchStatus(@RequestBody TTbDu tTbDu)
    {
        log.info("进入了 修改碳源投加 是否在本系统中允许投放（用于部分场景：计算异常 或者 想手动中断等） 接口");
        if(Objects.isNull(tTbDu.getActiveOne()) && Objects.isNull(tTbDu.getActiveTwo()))
            throw new RuntimeException("请输入要更改的状态");
        tTbDu.setID(LONG_1);
        this.tTbDuMapper.updateTTbDu(tTbDu);
        return R.ok("修改成功");
    }



    /**
     *首页-报表信息
     * @return
     */
    @GetMapping("/bigModel/smartAdd/homeList")
    public R<List<TShuju1>> homeList(@RequestParam(required = false, name = "timeBegin") String timeBegin, @RequestParam(required = false, name = "timeEnd") String timeEnd)
    {
        log.info("进入了 修改碳源投加 首页-报表信息 接口");
        TShuju1 req = TShuju1.builder().timeBegin(timeBegin).timeEnd(timeEnd).build();
        return R.ok(this.tShuju1Service.selectTShuju1List(req));
    }


    /**
     *首页-化验统计信息
     * @return
     */
    @GetMapping("/bigModel/smartAdd/homeCountInfo")
    public R<HomeCountInfo> homeCountInfo()
    {
        log.info("进入了 修改碳源投加 首页-化验统计信息 接口");
        return R.ok(this.frontService.homeCountInfo());
    }



}
